@@ -4,6 +4,8 @@
 #![feature(array_chunks)]
 #![feature(adt_const_params)]
 #![feature(doc_cfg)]
+#![feature(specialization)]
+// #![feature(auto_traits, negative_impls)]
 //! An extremely minimal super static type safe implementation of matrix types.
 //!
 //! While [`ndarray`](https://docs.rs/ndarray/latest/ndarray/) offers no compile time type checking
@@ -75,7 +77,7 @@
 //! // │ 5 5 5 │
 //! // └───────┘
 //! ```
-//! *This requires the `distribution` feature*
+//! *This requires the `distribution` feature.*
 //! ```ignore
 //! // From a given shape and with values sampled from a given distribution
 //! use rand::distributions::{Uniform,Standard};
@@ -116,6 +118,7 @@
 //! assert_eq!(c,MatrixSxD::try_from([vec![1, 2, 3], vec![4, 5, 6]]).unwrap());
 //! ```
 //! ### Arithmetic
+//! Most traits from [`std::ops`] are implemented.
 //! ```ignore
 //! use std::convert::TryFrom;
 //! use static_la::*;
@@ -137,6 +140,14 @@
 //! assert_eq!(a.slice_sxd::<{ 0..1 }>(0..2), MatrixSxD::try_from([vec![&1, &2]]).unwrap());
 //! assert_eq!(a.slice_sxs::<{ 0..1 }, { 0..2 }>(), MatrixSxS::from([[&1, &2]]));
 //! ```
+//! ### Transpose
+//! ```
+//! use static_la::MatrixSxS;
+//! let a = MatrixSxS::from([[1, 2, 3], [4, 5, 6]]);
+//! let b = a.transpose_ref(); // Please see docs
+//! let c = a.transpose();
+//! assert_eq!(c,MatrixSxS::<i32,3,2>::from([[1, 4], [2, 5],[3, 6]]));
+//! ```
 
 /// [`std::ops::Add`] Arithmetic addition operations.
 mod add;
@@ -171,7 +182,9 @@ mod mul_assign;
 mod partial_eq;
 /// Slicing functionality.
 mod slice;
-pub use slice::*;
+pub use slice::{SliceDxD, SliceDxS, SliceSxD, SliceSxS};
+/// Implementations relating to dimensions of matrices.
+mod dims;
 /// Constructing matrices with random values functionality.
 #[doc(cfg(feature = "distribution"))]
 #[cfg(feature = "distribution")]
@@ -180,13 +193,34 @@ mod distribution;
 mod sub;
 /// [`std::ops::SubAssign`] Arithmetic subtraction operations.
 mod sub_assign;
+/// Implementations relating to summations over matrices.
+mod sums;
 /// Transpose functionality.
 mod transpose;
+pub use transpose::*;
+/// [`std::ops::BitAnd`] Bitwise AND operation.
+mod bitand;
+/// [`std::ops::BitAndAssign`] Bitwise AND assignment operation.
+mod bitand_assign;
+/// [`std::ops::BitOr`] Bitwise OR operation.
+mod bitor;
+/// [`std::ops::BitOrAssign`] Bitwise OR assignment operation.
+mod bitor_assign;
+/// [`std::ops::BitXor`] Bitwise XOR operation.
+mod bitxor;
+/// [`std::ops::BitXorAssign`] Bitwise XOR assignment operation.
+mod bitxor_assign;
+/// [`std::ops::Neg`] Negation operations.
+mod neg;
+/// [`std::ops::Not`] Bitwise NOT operations.
+mod not;
+/// [`std::ops::Rem`] Remainder functionality.
+mod rem;
+/// [`std::ops::RemAssign`] Remainder assign functionality.
+mod rem_assign;
 /// [`std::convert::TryFrom`] Fallible value-to-value conversions.
 mod try_from;
 
-use std::convert::TryFrom;
-
 // Matrix types
 // --------------------------------------------------
 /// A `dynamic x dynamic` matrix where neither dimension is known at compile time.
@@ -201,49 +235,6 @@ pub struct MatrixDxD<T> {
     columns: usize,
     rows: usize,
 }
-impl<T> MatrixDxD<T> {
-    /// Number of elements in matrix.
-    pub fn len(&self) -> usize {
-        self.data.len()
-    }
-    /// Number of columns.
-    pub fn columns(&self) -> usize {
-        self.columns
-    }
-    /// Number of rows.
-    pub fn rows(&self) -> usize {
-        self.rows
-    }
-}
-impl<T: std::iter::Sum<T> + Clone> MatrixDxD<T> {
-    /// Gets sum of all elements.
-    pub fn sum(&self) -> T {
-        self.data.iter().cloned().sum()
-    }
-    /// Gets the sum of each row.
-    pub fn row_sum(&self) -> ColumnVectorD<T> {
-        ColumnVectorD::from(
-            self.data
-                .chunks_exact(self.columns)
-                .map(|r| [r.iter().cloned().sum()])
-                .collect::<Vec<_>>(),
-        )
-    }
-    /// Gets the sum of each column.
-    pub fn column_sum(&self) -> RowVectorD<T> {
-        RowVectorD::try_from([(0..self.columns)
-            .map(|i| {
-                self.data
-                    .iter()
-                    .skip(i)
-                    .step_by(self.columns)
-                    .cloned()
-                    .sum()
-            })
-            .collect::<Vec<_>>()])
-        .unwrap()
-    }
-}
 /// A `dynamic x static` matrix where the columns dimension is known at compile time.
 /// ```
 /// let _ = static_la::MatrixDxS::from(vec![[1, 2, 3], [4, 5, 6]]);
@@ -254,48 +245,6 @@ pub struct MatrixDxS<T, const COLUMNS: usize> {
     data: Vec<T>,
     rows: usize,
 }
-impl<T, const COLUMNS: usize> MatrixDxS<T, COLUMNS> {
-    /// Number of elements in matrix.
-    pub fn len(&self) -> usize {
-        self.data.len()
-    }
-    /// Number of columns.
-    pub const fn columns(&self) -> usize {
-        COLUMNS
-    }
-    /// Number of rows.
-    pub fn rows(&self) -> usize {
-        self.rows
-    }
-}
-impl<T: std::iter::Sum<T> + Copy + Default + std::fmt::Debug, const COLUMNS: usize>
-    MatrixDxS<T, COLUMNS>
-where
-    [(); 1 * COLUMNS]:,
-{
-    /// Gets sum of all elements.
-    pub fn sum(&self) -> T {
-        self.data.iter().cloned().sum()
-    }
-    /// Gets the sum of each row.
-    pub fn row_sum(&self) -> ColumnVectorD<T> {
-        ColumnVectorD::from(
-            self.data
-                .chunks_exact(COLUMNS)
-                .map(|r| [r.iter().cloned().sum()])
-                .collect::<Vec<_>>(),
-        )
-    }
-    /// Gets the sum of each column.
-    pub fn column_sum(&self) -> RowVectorS<T, COLUMNS> {
-        // Will dropping the `Default` and `Copy` traits to use `try_into` affect performance?
-        let mut sums: [T; COLUMNS] = [Default::default(); COLUMNS];
-        for i in 0..COLUMNS {
-            sums[i] = self.data.iter().skip(i).step_by(COLUMNS).cloned().sum();
-        }
-        RowVectorS::from([sums])
-    }
-}
 /// A `static x dynamic` matrix where the rows dimension is known at compile time.
 /// ```
 /// use std::convert::TryFrom;
@@ -307,52 +256,6 @@ pub struct MatrixSxD<T, const ROWS: usize> {
     data: Vec<T>,
     columns: usize,
 }
-impl<T, const ROWS: usize> MatrixSxD<T, ROWS> {
-    /// Number of elements in matrix.
-    pub fn len(&self) -> usize {
-        self.data.len()
-    }
-    /// Number of rows.
-    pub const fn rows(&self) -> usize {
-        ROWS
-    }
-    /// Number of columns.
-    pub fn columns(&self) -> usize {
-        self.columns
-    }
-}
-
-impl<T: std::iter::Sum<T> + Copy + Default + std::fmt::Debug, const ROWS: usize> MatrixSxD<T, ROWS>
-where
-    [(); ROWS * 1]:,
-{
-    /// Gets sum of all elements.
-    pub fn sum(&self) -> T {
-        self.data.iter().cloned().sum()
-    }
-    /// Gets the sum of each row.
-    pub fn row_sum(&self) -> ColumnVectorS<T, ROWS> {
-        let mut sums: [[T; 1]; ROWS] = [[Default::default(); 1]; ROWS];
-        for (i, row) in (0..ROWS).zip(self.data.chunks_exact(self.columns)) {
-            sums[i][0] = row.iter().cloned().sum();
-        }
-        ColumnVectorS::from(sums)
-    }
-    /// Gets the sum of each column.
-    pub fn column_sum(&self) -> RowVectorD<T> {
-        RowVectorD::try_from([(0..self.columns)
-            .map(|i| {
-                self.data
-                    .iter()
-                    .skip(i)
-                    .step_by(self.columns)
-                    .cloned()
-                    .sum()
-            })
-            .collect::<Vec<_>>()])
-        .unwrap()
-    }
-}
 /// A `static x static` matrix where both dimensions are known at compile time.
 /// ```
 /// let _ = static_la::MatrixSxS::<i32,2,3>::from([[1, 2, 3], [4, 5, 6]]);
@@ -365,54 +268,6 @@ where
     /// Underlying data.
     data: [T; ROWS * COLUMNS],
 }
-impl<T, const ROWS: usize, const COLUMNS: usize> MatrixSxS<T, ROWS, COLUMNS>
-where
-    [(); ROWS * COLUMNS]:,
-{
-    /// Number of elements in matrix.
-    pub const fn len(&self) -> usize {
-        ROWS * COLUMNS
-    }
-    /// Number of rows.
-    pub const fn rows(&self) -> usize {
-        ROWS
-    }
-    /// Number of columns.
-    pub const fn columns(&self) -> usize {
-        COLUMNS
-    }
-}
-impl<
-        T: std::iter::Sum<T> + Copy + Default + std::fmt::Debug,
-        const ROWS: usize,
-        const COLUMNS: usize,
-    > MatrixSxS<T, ROWS, COLUMNS>
-where
-    [(); ROWS * COLUMNS]:,
-    [(); ROWS * 1]:,
-    [(); 1 * COLUMNS]:,
-{
-    /// Gets sum of all elements.
-    pub fn sum(&self) -> T {
-        self.data.iter().cloned().sum()
-    }
-    /// Gets the sum of each row.
-    pub fn row_sum(&self) -> ColumnVectorS<T, ROWS> {
-        let mut sums: [[T; 1]; ROWS] = [[Default::default(); 1]; ROWS];
-        for (i, row) in (0..ROWS).zip(self.data.chunks_exact(COLUMNS)) {
-            sums[i][0] = row.iter().cloned().sum();
-        }
-        ColumnVectorS::from(sums)
-    }
-    /// Gets the sum of each column.
-    pub fn column_sum(&self) -> RowVectorS<T, COLUMNS> {
-        let mut sums: [T; COLUMNS] = [Default::default(); COLUMNS];
-        for i in 0..COLUMNS {
-            sums[i] = self.data.iter().skip(i).step_by(COLUMNS).cloned().sum();
-        }
-        RowVectorS::from([sums])
-    }
-}
 // Vector aliases
 // --------------------------------------------------
 /// A matrix with 1 column and a dynamic number of rows.
